.. gossip documentation master file, created by
   sphinx-quickstart on Wed Apr 30 23:12:15 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome - Gossip |release| Docs
================================

Gossip is a Python library enabling you to define, register and call hooks in various ways.

Hooks can be organized into groups, controlling the behavior of a hook group as a whole.

Contents:

.. toctree::
   :maxdepth: 2

   basics
   hook_groups
   advanced
   error_handling
   hook_dependencies
   sphinx_ext
   changelog
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

